@@ -10,8 +10,8 @@ class DevelopEggs(object):
 
     def _validate(self, warnings, errors):
         assert_condition(
-            errors, isinstance(self[KEY], dict),
-            "{0} must be a dict! found {1} instead".format(KEY, type(self[KEY]))
+            errors, isinstance(self[KEY], list),
+            "{0} must be a list! found {1} instead".format(KEY, type(self[KEY]))
         )
 
     @property
