@@ -1,4 +1,4 @@
-from pip.req.req_set import RequirementSet
+from pip.req import RequirementSet
 
 
 class UraniumRequirementSet(RequirementSet):
