@@ -1,9 +1,8 @@
 import logging
-import os
 from .classloader import ClassLoader
-from .config import load_config_from_file
 from .pip_manager import PipManager
 from .buildout_adapter import BuildoutAdapter
+from .isotope_runner import IsotopeRunner
 from .phases import (AFTER_EGGS, BEFORE_EGGS)
 
 LOGGER = logging.getLogger(__name__)
@@ -15,20 +14,22 @@ class UraniumException(Exception):
 
 class Uranium(object):
 
-    def __init__(self, file_path):
-        self._root = os.path.abspath(os.curdir)
-        self._config = load_config_from_file(file_path)
+    def __init__(self, config, root):
+        self._root = root
+        self._config = config
 
-        self._pip = PipManager(index_urls=self._config.indexes)
+        self._pip = PipManager(index_urls=self._config.indexes,
+                               versions=self.config.versions)
         self._classloader = ClassLoader(self._pip)
 
         self._buildout = BuildoutAdapter(self, self._classloader)
+        self._isotope = IsotopeRunner(self, self._classloader)
 
-        errors = self._config.validate()
-        if errors:
-            for error in errors:
-                LOGGER.error(error)
-            raise UraniumException("uranium.yaml is not valid.")
+        self._validate_config()
+
+    @property
+    def config(self):
+        return self._config
 
     @property
     def root(self):
@@ -39,10 +40,18 @@ class Uranium(object):
         self._install_eggs()
         self.run_phase(AFTER_EGGS)
 
+    def run_part(self, name):
+        part = self._config.get_part(name)
+
+        runner = self._buildout if part.is_recipe else self._isotope
+
+        part_instance = runner.get_part_instance(part)
+        runner.install_part(part_instance)
+
     def run_phase(self, phase):
         part_names = self._config.phases.get(phase.key, [])
         for name in part_names:
-            self._run_part(name, phase)
+            self.run_part(name, phase)
 
     def _install_eggs(self):
         develop_eggs = self._config.get('develop-eggs')
@@ -59,10 +68,11 @@ class Uranium(object):
             self._pip.add_eggs(eggs)
         self._pip.install()
 
-    def _run_part(self, name, phase):
-        part = self._config.get_part(name)
-        if part.is_recipe:
-            part_instance = self._buildout.get_part_instance(part)
-            self._buildout.install_part(part_instance)
-        elif part.is_isotope:
-            pass
+    def _validate_config(self):
+        warnings, errors = self._config.validate()
+        for warning in warnings:
+            LOGGER.warn(warning)
+        if errors:
+            for error in errors:
+                LOGGER.error(error)
+            raise UraniumException("uranium.yaml is not valid.")
